
# Slot: enums


enumerated ranges

URI: [linkml:enums](https://w3id.org/linkml/enums)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [EnumDefinition](EnumDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
